@@ -1,18 +1,18 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CONFIGUREPLUGINSWIDGET_H
-#define CONFIGUREPLUGINSWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "pimcommon_export.h"
+#include <QWidget>
 class QSplitter;
 class QTextEdit;
 class KMessageWidget;
-namespace PimCommon {
+namespace PimCommon
+{
 class ConfigurePluginsListWidget;
 /**
  * @brief The ConfigurePluginsWidget class
@@ -24,7 +24,7 @@ class PIMCOMMON_EXPORT ConfigurePluginsWidget : public QWidget
 public:
     explicit ConfigurePluginsWidget(QWidget *parent = nullptr);
     explicit ConfigurePluginsWidget(ConfigurePluginsListWidget *configurePluginListWidget, QWidget *parent = nullptr);
-    ~ConfigurePluginsWidget();
+    ~ConfigurePluginsWidget() override;
 
     void save();
     void defaults();
@@ -47,4 +47,3 @@ private:
     KMessageWidget *mMessageWidget = nullptr;
 };
 }
-#endif // CONFIGUREPLUGINSWIDGET_H
