@@ -1,15 +1,16 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CUSTOMTOOLSPLUGINMANAGER_H
-#define CUSTOMTOOLSPLUGINMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "pimcommon_export.h"
-namespace PimCommon {
+#include <QObject>
+#include <memory>
+namespace PimCommon
+{
 class CustomToolsPlugin;
 class CustomToolsPluginManagerPrivate;
 /**
@@ -23,11 +24,11 @@ public:
     static CustomToolsPluginManager *self();
 
     explicit CustomToolsPluginManager(QObject *parent = nullptr);
-    ~CustomToolsPluginManager();
+    ~CustomToolsPluginManager() override;
 
     Q_REQUIRED_RESULT QVector<PimCommon::CustomToolsPlugin *> pluginsList() const;
+
 private:
-    CustomToolsPluginManagerPrivate *const d;
+    std::unique_ptr<CustomToolsPluginManagerPrivate> const d;
 };
 }
-#endif // CUSTOMTOOLSPLUGINMANAGER_H
